@@ -13,6 +13,7 @@ if (isset( $_POST["id"      ] )) { $_var[      "id"]=$_POST["id"] ;      }
 if (isset( $_POST["nickname"] )) { $_var["nickname"]=$_POST["nickname"]; }
 if (isset( $_POST["distpath"] )) { $_var["distpath"]=$_POST["distpath"]; }
 if (isset( $_POST["distaccount"] )) { $_var["distaccount"]=$_POST["distaccount"]; }
+if (isset( $_POST["docommand"] )) { $_var["docommand"]=$_POST["docommand"]; }
 if (isset( $_POST["memo"    ] )) { $_var[    "memo"]=$_POST["memo"];     }
 if (isset( $_POST["mode"    ] )) { $_var[    "mode"]=$_POST["mode"];     } else {  $_var["mode"]=0; }
 if (isset( $_POST["devname" ] )) { $_var[ "devname"]=$_POST["devname"];  }
@@ -27,7 +28,8 @@ if (isset( $_POST["flags128" ] )) { $_var["flags128" ]=$_POST["flags128" ];
 if (isset( $_POST["flags256" ] )) { $_var["flags256" ]=$_POST["flags256" ];     } else {  $_var["flags256"   ]=0; }
 if (isset( $_POST["flags512" ] )) { $_var["flags512" ]=$_POST["flags512" ];     } else {  $_var["flags512"   ]=0; }
 if (isset( $_POST["flags1024"] )) { $_var["flags1024"]=$_POST["flags1024"];     } else {  $_var["flags1024"   ]=0; }
- $_var["flags"]= $_var["flags1" ]+ $_var["flags2" ]+ $_var["flags4" ]+ $_var["flags8" ]+ $_var["flags16" ]+ $_var["flags32"   ]+ $_var["flags64"   ]+ $_var["flags128"   ]+ $_var["flags256"   ]+ $_var["flags512"   ]+ $_var["flags1024"   ]; 
+if (isset( $_POST["flags2048"] )) { $_var["flags2048"]=$_POST["flags2048"];     } else {  $_var["flags2048"   ]=0; }
+ $_var["flags"]= $_var["flags1" ]+ $_var["flags2" ]+ $_var["flags4" ]+ $_var["flags8" ]+ $_var["flags16" ]+ $_var["flags32"   ]+ $_var["flags64"   ]+ $_var["flags128"   ]+ $_var["flags256"   ]+ $_var["flags512"   ]+ $_var["flags1024"   ]+ $_var["flags2048"   ]; 
 
 
 
@@ -58,7 +60,7 @@ if ( 0 == isset( $_var["id"] )){
 // print("<h1>登録済みUSBデバイス一覧</h1>");
 
 
-        $sql = "select id,id_serial,nickname,memo,flags,distpath,distaccount from media";
+        $sql = "select id,id_serial,nickname,memo,flags,distpath,distaccount,docommand from media";
         $results = mysql_db_query($db,$sql);
         if (!$results)
         {
@@ -71,7 +73,7 @@ if ( 0 == isset( $_var["id"] )){
 <table>
 <tbody>
 <tr>
-<td colspan="4" rowspan="11" style="vertical-align: top;"><br>
+<td colspan="4" rowspan="13" style="vertical-align: top;"><br>
 <table style="border: 0pt none ;" width="100%">
 <tbody>
 <tr>
@@ -104,12 +106,11 @@ if ( 1 == isset( $_var["id"] )) {
 </tbody>
 </table>
 
-
 <h1>登録済みUSBデバイス一覧</h1>
 </td>
 <th style="vertical-align: top;">┏<br>
 </th>
-<td colspan="11" rowspan="1" style="vertical-align: top;">＊未登録<br>
+<td colspan="14" rowspan="1" style="vertical-align: top;">＊未登録<br>
 </td>
 </tr>
 <tr>
@@ -117,7 +118,7 @@ if ( 1 == isset( $_var["id"] )) {
 </th>
 <th style="vertical-align: top;">┏
 </th>
-<td colspan="10" rowspan="1" style="vertical-align: top;">＊使用禁止<br>
+<td colspan="13" rowspan="1" style="vertical-align: top;">＊使用禁止<br>
 </td>
 </tr>
 <tr>
@@ -127,7 +128,7 @@ if ( 1 == isset( $_var["id"] )) {
 </th>
 <th style="vertical-align: top;">┏
 </th>
-<td colspan="9" rowspan="1" style="vertical-align: top;">＊信頼済(管理者
+<td colspan="12" rowspan="1" style="vertical-align: top;">＊信頼済(管理者
 のみ利用)<br>
 </td>
 </tr>
@@ -140,7 +141,7 @@ if ( 1 == isset( $_var["id"] )) {
 </th>
 <th style="vertical-align: top;">┏
 </th>
-<td colspan="8" rowspan="1" style="vertical-align: top;">（操作前確認<br>
+<td colspan="11" rowspan="1" style="vertical-align: top;">操作前確認<br>
 </td>
 </tr>
 <tr>
@@ -154,7 +155,7 @@ if ( 1 == isset( $_var["id"] )) {
 </th>
 <th style="vertical-align: top;">┏
 </th>
-<td colspan="7" rowspan="1" style="vertical-align: top;">（削除ファイルを
+<td colspan="10" rowspan="1" style="vertical-align: top;">削除ファイルを
 バックアップ<br>
 </td>
 </tr>
@@ -171,7 +172,7 @@ if ( 1 == isset( $_var["id"] )) {
 </th>
 <th style="vertical-align: top;">┏
 </th>
-<td colspan="6" rowspan="1" style="vertical-align: top;">実行ファイル削除<br>
+<td colspan="9" rowspan="1" style="vertical-align: top;">実行ファイル削除<br>
 </td>
 </tr>
 <tr>
@@ -189,7 +190,7 @@ if ( 1 == isset( $_var["id"] )) {
 </th>
 <th style="vertical-align: top;">┏
 </th>
-<td colspan="5" rowspan="1" style="vertical-align: top;">検疫済ファイルを外
+<td colspan="8" rowspan="1" style="vertical-align: top;">検疫済ファイルを外
 部にコピー
 </td>
 </tr>
@@ -210,7 +211,7 @@ if ( 1 == isset( $_var["id"] )) {
 </th>
 <th style="vertical-align: top;">┏
 </th>
-<td colspan="4" rowspan="1" style="vertical-align: top;">フォーマット<br>
+<td colspan="7" rowspan="1" style="vertical-align: top;">フォーマット<br>
 </td>
 </tr>
 <tr>
@@ -232,7 +233,7 @@ if ( 1 == isset( $_var["id"] )) {
 </th>
 <th style="vertical-align: top;">┏
 </th>
-<td colspan="3" rowspan="1" style="vertical-align: top;">＊使用停止<br>
+<td colspan="6" rowspan="1" style="vertical-align: top;">＊使用停止<br>
 </td>
 </tr>
 <tr>
@@ -256,7 +257,37 @@ if ( 1 == isset( $_var["id"] )) {
 </th>
 <th style="vertical-align: top;">┏
 </th>
-<td colspan="2" rowspan="1" style="vertical-align: top;">検疫後共有公開<br>
+<td colspan="5" rowspan="1" style="vertical-align: top;">検疫後共有公開
+</td>
+</tr>
+<tr>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top; text-align: center;">┏</th>
+<td colspan="4" rowspan="1" style="vertical-align: top;">持出可（書込OK）</td>
+</tr>
+<tr>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top; text-align: center;">┏</th>
+<td colspan="3" rowspan="1" style="vertical-align: top;">共有リンクを表示しない<br>
 </td>
 </tr>
 <tr>
@@ -280,31 +311,48 @@ if ( 1 == isset( $_var["id"] )) {
 </th>
 <th style="vertical-align: top;">|<br>
 </th>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top; text-align: center;">|</th>
 <th style="vertical-align: top;">┏
 </th>
-<td colspan="1" rowspan="1" style="vertical-align: top;">持出可（書込OK）</td>
+<td colspan="2" rowspan="1" style="vertical-align: top;">コピー先を表示しない</td>
 </tr>
-
 <tr>
-<th style="vertical-align: top;"></th>
+<th style="vertical-align: top;"><br>
+</th>
 <th style="vertical-align: top;">USB ID</th>
 <th style="vertical-align: top;">名前</th>
 <th style="vertical-align: top;">説明</th>
+<th style="vertical-align: top;">|<br>
+</th>
+<th style="vertical-align: top;">|<br>
+</th>
+<th style="vertical-align: top;">|<br>
+</th>
+<th style="vertical-align: top;">|<br>
+</th>
+<th style="vertical-align: top;">|<br>
+</th>
+<th style="vertical-align: top;">|<br>
+</th>
+<th style="vertical-align: top;">|<br>
+</th>
+<th style="vertical-align: top;">|<br>
+</th>
+<th style="vertical-align: top;">|<br>
+</th>
+<th style="vertical-align: top;">|<br>
+</th>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top; text-align: center;">|</th>
+<th style="vertical-align: top;">|<br>
 </th>
-<th style="vertical-align: top;">|<br> </th>
-<th style="vertical-align: top;">|<br> </th>
-<th style="vertical-align: top;">|<br> </th>
-<th style="vertical-align: top;">|<br> </th>
-<th style="vertical-align: top;">|<br> </th>
-<th style="vertical-align: top;">|<br> </th>
-<th style="vertical-align: top;">|<br> </th>
-<th style="vertical-align: top;">|<br> </th>
-<th style="vertical-align: top;">|<br> </th>
-<th style="vertical-align: top;">|<br> </th>
-<th style="vertical-align: top;">|<br> </th>
 <th>外部コピー先</th>
+<th style="vertical-align: top;">コマンド<br>
+</th>
 </tr>
 
+
 <?php
         while($row=mysql_fetch_array($results))
         {
@@ -318,7 +366,7 @@ if ( 1 == isset( $_var["id"] )) {
 		} else {
                   print ("<td>│</td>");
                 }
-                for ( $i=1 ; $i<=512 ; $i = $i * 2 ) {
+                for ( $i=1 ; $i<=2048 ; $i = $i * 2 ) {
    		  if ( 0 == ( $i & $row[4]) ){
 		    $check="│";
 		  } else {
@@ -333,6 +381,9 @@ if ( 1 == isset( $_var["id"] )) {
 		print ($row[5]);  // distpath
                 print("</td>");
                 print("<td>");
+		print ($row[7]);  // docommand
+                print("</td>");
+                print("<td>");
 		if (1 == $_var["adminmode"]){
 ?>
 		<form action="regist.php" method="post">
@@ -365,7 +416,7 @@ exit(0);
 }
 // ----------------------------------------------- list mode end-----------------------
 
-$sql = "select id_serial,nickname,flags,memo,distpath,distaccount from media where id=\"".$_var["id"]."\"";
+$sql = "select id_serial,nickname,flags,memo,distpath,distaccount,docommand from media where id=\"".$_var["id"]."\"";
 // echo $sql;
 $results = mysql_db_query($db,$sql);
 if (!$results)
@@ -382,6 +433,7 @@ while($row=mysql_fetch_array($results))
        $org["memo"       ] =($row[3]);
        $org["distpath"   ] =($row[4]);
        $org["distaccount"] =($row[5]);
+       $org["docommand"  ] =($row[6]);
  }
 mysql_free_result($results);
 if ( 0 == strcmp("regist", $_var["mode"])){
@@ -391,13 +443,14 @@ if ( 0 == strcmp("regist", $_var["mode"])){
 		flags      =\"".$_var["flags"]."\", 
 		memo       =\"".$_var["memo"]."\", 
 		distpath   =\"".$_var["distpath"]."\",
-		distaccount=\"".$_var["distaccount"]."\" 
+		distaccount=\"".$_var["distaccount"]."\", 
+		docommand  =\"".$_var["docommand"]."\" 
 	 where id=\"".$_var["id"]."\"";
         
         $results = mysql_db_query($db,$sql);
         if (!$results)
         {
-print "$sql";
+// print "$sql";
                 print("SQL execution error");
                 exit;
         }
@@ -423,6 +476,9 @@ print "$sql";
 ?>
 <h1>登録しました</h1>
 <b>一旦抜いて、もう一度差し直してください</b>
+<br>
+<br>
+<a href="regist.php">登録一覧を見る</a>
 <?php
 //----------------------------new regist mode end -------------------
 } else if ( 0 == strcmp("change",$_var["mode"] )) {
@@ -459,6 +515,10 @@ print("<h1>登録情報変更</h1>");
 <input type="checkbox" name=flags256  value="256" <?php if ( 0 != ( 256 &$org["flags"]) ) { print "checked"; } ?>>検疫後共有公開
 <br>
 <input type="checkbox" name=flags512  value="512" <?php if ( 0 != ( 512 &$org["flags"]) ) { print "checked"; } ?>>持出可（書込OK） 
+<br>
+<input type="checkbox" name=flags1024  value="1024" <?php if ( 0 != ( 1024 &$org["flags"]) ) { print "checked"; } ?>>共有リンクを表示しない
+<br>
+<input type="checkbox" name=flags2048  value="2048" <?php if ( 0 != ( 2048 &$org["flags"]) ) { print "checked"; } ?>>コピー先を表示しない
 
 <br>
 ルールは上から順番に適用されます。＊印のついているものは、そこでストップします。＃印のついているものは現在使用できません
@@ -467,6 +527,8 @@ print("<h1>登録情報変更</h1>");
 <br>
 <input type="text" name=distaccount value="<?php echo $org["distaccount"]; ?>">コピー先PATHへのユーザ名、パスワード　USERNAME%PASSWORDと入力してください。必要ない場合も%のみ入力してください
 <br>
+<input type="text" name=docommand value="<?php echo $org["docommand"]; ?>">処理後に実行するコマンド /usr/bin/micon -a bz_melody 960 C4 G4 C5 で音が鳴ります(KUROBOX)
+<br>
 <input type="submit">
 <input type="hidden" name="id" value="<?php echo $_var["id"]; ?>">
 <input type="hidden" name="mode" value="regist">
@@ -506,6 +568,11 @@ print("<h1>このUSBデバイス(".$org["nickname"].")は未登録です</h1>");
 <input type="checkbox" name=flags256  value="256" <?php if ( 0 != ( 256 &$org["flags"]) ) { print "checked"; } ?>>検疫後共有公開
 <br>
 <input type="checkbox" name=flags512  value="512" <?php if ( 0 != ( 512 &$org["flags"]) ) { print "checked"; } ?>>持出可（書込OK） 
+<br>
+<input type="checkbox" name=flags1024  value="1024" <?php if ( 0 != ( 1024 &$org["flags"]) ) { print "checked"; } ?>>共有リンクを表示しない
+<br>
+<input type="checkbox" name=flags2048  value="2048" <?php if ( 0 != ( 2048 &$org["flags"]) ) { print "checked"; } ?>>コピー先を表示しない
+
 <br>
 
 ルールは上から順番に適用されます。＊印のついているものは、そこでストップします。＃印のついているものは現在使用できません
@@ -514,6 +581,8 @@ print("<h1>このUSBデバイス(".$org["nickname"].")は未登録です</h1>");
 <br>
 <input type="text" name=distaccount value="<?php echo $org["distaccount"]; ?>">コピー先PATHへのユーザ名、パスワード　USERNAME%PASSWORDと入力してください。必要ない場合も%のみ入力してください
 <br>
+<input type="text" name=docommand value="<?php echo $org["docommand"]; ?>">処理後に実行するコマンド  /usr/bin/micon -a bz_melody 960 C4 G4 C5 で音が鳴ります(KUROBOX)
+<br>
 <input type="submit">
 <input type="hidden" name="id" value="<?php echo $_var["id"]; ?>">
 <input type="hidden" name="mode" value="regist">
@@ -536,7 +605,7 @@ $flags = $org["flags"];
   if ( 128 == (  128 & $flags )) { $actions = $actions."「使用停止」"; }
   if ( 256 == (  256 & $flags )) { $actions = $actions."「検疫後共有公開」"; }
   if ( 512 == (  512 & $flags )) { $actions = $actions."「持出可」"; }
-
+  if ( strcmp($org["docommand"],'')!=0  ){ $actions = $actions."「コマンド実行」"; }
   if (   4 == (    4 & $flags )) {
 //----------------------------actionconfirm mode start-------------
 
@@ -607,6 +676,7 @@ $flags = $org["flags"];
   if ( 128 == (  128 & $flags )) { $actions = $actions."「使用停止」"; }
   if ( 256 == (  256 & $flags )) { $actions = $actions."「検疫後共有公開」"; }
   if ( 512 == (  512 & $flags )) { $actions = $actions."「持出可」"; }
+  if ( strcmp($org["docommand"],'')!=0  ){ $actions = $actions."「コマンド実行」"; }
 
   if (   4 == (    4 & $flags )) {
 //----------------------------DOACTION mode start-------------
@@ -648,6 +718,9 @@ $flags = $org["flags"];
       passthru("sudo smbmount ".$org["distpath"]." /mnt/".$_var["id"]." -o username=".$org["distaccount"]);
       $nowstring = date("Ymd-His");
       passthru("sudo mkdir -p /mnt/".$_var["id"]."/".$nowstring);
+      if ( 2048 != ( 2048 & $flags )) {
+	 print "(コピー先: <a href=\"file:".$org["distpath"]."/".$nowstring."\">".$org["distpath"]."/".$nowstring."</a>)";
+      }
       echo("sudo cp -a /mnt".$_var["devname"]."/ /mnt/".$_var["id"]."/".$nowstring);
       passthru("sudo cp -a /mnt".$_var["devname"]."/ /mnt/".$_var["id"]."/".$nowstring);
       echo("sudo umount ".$_var["devname"]);
@@ -673,6 +746,12 @@ $flags = $org["flags"];
       #passthru("find /etc -name a*");
       print "</pre>";
   }
+  if ( strcmp($org["docommand"],'')!=0  ){
+      $action = "「コマンド実行」";
+      print $action;
+      passthru("sudo ".$org["docommand"]);
+       
+  }
   if ( 128 == (  128 & $flags )) {
       $action = "「使用停止」";
       print $action;
@@ -686,13 +765,16 @@ $flags = $org["flags"];
           print $action;
           flush(); ob_end_flush(); ob_start();
           passthru("sudo mount ".$_var["devname"]." /var/squarantine/usbstorages/".$org["nickname"]);
+      //    echo ("sudo mount ".$_var["devname"]." /var/squarantine/usbstorages/".$org["nickname"]);
        } else {
           passthru("sudo mount -r ".$_var["devname"]." /var/squarantine/usbstorages/".$org["nickname"]);
+      //    echo ("sudo mount -r ".$_var["devname"]." /var/squarantine/usbstorages/".$org["nickname"]);
        }
        print "<h2>終了しました</h2>";
       passthru("date");
-       print "<a href=\"file:".$conf["SAMBAPATH"]."\">こちらからアクセスしてください</a>";
-
+       if ( 1024 != ( 1024 & $flags )) {
+	 print "<a href=\"file:".$conf["SAMBAPATH"]."\">こちらからアクセスしてください</a>";
+	}
     }
   }
 }
